<?php

namespace Repositories;

use Util\InstanceProvider;

class Operador
{
    /**
     * @param $cdOperador
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getOperatorParams($cdOperador, $nrOrg)
    {
        $query = "SELECT IDSTATUSENHA
                    FROM OPERADOR
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG = :NRORG";

        $params = array(
            'CDOPERADOR' => $cdOperador,
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }

    /**
     * @param $cdOperador
     * @param $nrOrg
     * @param $idStatuSenha
     * @return \Doctrine\DBAL\Driver\Statement
     * @throws \Doctrine\DBAL\DBALException
     */
    public function saveOperatorPasswordStatus($cdOperador, $nrOrg, $idStatuSenha)
    {
        $query = "UPDATE OPERADOR
                     SET IDSTATUSENHA = :IDSTATUSENHA
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG = :NRORG";

        $params = array(
            'IDSTATUSENHA' => $idStatuSenha,
            'CDOPERADOR' => $cdOperador,
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    /**
     * @param $nrParcNegocio
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getOperatorAccessProfile($nrParcNegocio, $nrOrg)
    {
        $query = "SELECT PP.NRPERFILACESSO AS ID, PA.IDPERFILACESSOADM
                    FROM PERFACESSPARC PP
              INNER JOIN PERFILACESSO PA ON PA.NRPERFILACESSO = PP.NRPERFILACESSO
                   WHERE PP.NRORG = :NRORG
                     AND PP.NRPARCNEGOCIO = :NRPARCNEGOCIO
                     AND PP.IDATIVO = 'S'
                     AND (PP.DTVALIDADE IS NULL OR TRUNC(PP.DTVALIDADE) >= TRUNC(SYSDATE))";

        $params = array(
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->fetchAll($query, $params);
    }

    /**
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getBranchAccessProfile($userId, $nrOrg)
    {
        $query = "SELECT DISTINCT PP.NRPERFILACESSO AS ID, PA.IDPERFILACESSOADM
                    FROM PERFACESSFILI PP
              INNER JOIN PERFILACESSO PA ON PA.NRPERFILACESSO = PP.NRPERFILACESSO
                   WHERE PP.NRORG = :NRORG
                     AND PP.CDOPERADOR = :CDOPERADOR
                     AND PP.IDATIVO = 'S'
                     AND (PP.DTVALIDADE IS NULL OR TRUNC(PP.DTVALIDADE) >= TRUNC(SYSDATE))";

        $params = array(
            'NRORG'      => $nrOrg,
            'CDOPERADOR' => $userId
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->fetchAll($query, $params);
    }

    /**
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getIdUtlPerfilFilialParamGeral($nrOrg)
    {
        $query = "SELECT IDUTLPERFILFILIAL
                    FROM PARAMGERAL
                   WHERE NRORG = :NRORG";

        $params = array('NRORG' => $nrOrg);

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        try {
            $result = $entityManager->getConnection()->fetchAll($query, $params);
            return !empty($result) ? $result[0] : $result;
        } catch (\Exception $e) {
            return array(
                'IDUTLPERFILFILIAL' => "N"
            );
        }
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @return array
     * @throws \Exception
     */
    public function getCdPerfilSelecionado($nrOrg, $cdOperator)
    {
        $query = "SELECT OP.CDPERFILSELECIONADO AS ID, PA.IDPERFILACESSOADM
                    FROM OPERADOR OP
              INNER JOIN PERFILACESSO PA ON PA.NRPERFILACESSO = OP.CDPERFILSELECIONADO
                   WHERE OP.NRORG = :NRORG
                     AND OP.CDOPERADOR = :CDOPERADOR";

        $params = array('NRORG' => $nrOrg, 'CDOPERADOR' => $cdOperator);

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        try {
            return $entityManager->getConnection()->fetchAll($query, $params);
        } catch (\Exception $e) {
            return array(
                array(
                    'ID' => null, 'IDPERFILACESSOADM' => 'N'
                )
            );
        }
    }

    /**
     * @param $cdoperador
     * @param $nrorg
     * @return \Doctrine\DBAL\Driver\ResultStatement
     * @throws \Exception
     */
    public function updateLastAccess($cdoperador, $nrorg)
    {
        $query = "UPDATE OPERADOR
                     SET DTULTACESOPER = SYSDATE
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG = :NRORG";

        $params = array(
            'CDOPERADOR' => $cdoperador,
            'NRORG' => $nrorg
        );
        try {
            $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrorg);
            $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

            return $entityManager->getConnection()->executeQuery($query, $params);
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        };
    }
}